==> mediawiki-1.14.0.tgz: mediawiki/languages/messages/MessagesZh_hk.php <==
<?php
/** Chinese (Hong Kong) (‪中文(香港)‬)
 *
 * @ingroup Language
 * @file
 *
 * @author Yuyu
 */

$fallback = 'zh-hant';

$messages = array(
# User preference toggles
'tog-watchlisthidebots' => '監視列表中隱藏機械人的編輯',

# Dates
'sunday'        => '星期日',
'monday'        => '星期一',
'tuesday'       => '星期二',
'wednesday'     => '星期三',
'thursday'      => '星期四',
'friday'        => '星期五',
'saturday'      => '星期六',
'sun'           => '日',
'mon'           => '一',
'tue'           => '二',
'wed'           => '三',
'thu'           => '四',
'fri'           => '五',
'sat'           => '六',
'january'       => '1月',
'february'      => '2月',
'march'         => '3月',
'april'         => '4月',
'may_long'      => '5月',
'june'          => '6月',
'july'          => '7月',
'august'        => '8月',
'september'     => '9月',
'october'       => '10月',
'november'      => '11月',
'december'      => '12月',
'january-gen'   => '一月',
'february-gen'  => '二月',
'march-gen'     => '三月',
'april-gen'     => '四月',
'may-gen'       => '五月',
'june-gen'      => '六月',
'july-gen'      => '七月',
'august-gen'    => '八月',
'september-gen' => '九月',
'october-gen'   => '十月',
'november-gen'  => '十一月',
'december-gen'  => '十二月',
'jan'           => '1月',

'printableversion' => '可打印版',
'print'            => '打印',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'privacy'     => '私隱政策',
'privacypage' => 'Project:私隱政策',

# Groups
'group-bot' => '機械人',

'group-bot-member' => '機械人',

'grouppage-bot' => '{{ns:project}}:機械人',

# Recent changes
'rcshowhidebots' => '$1機械人的編輯',

# Tooltip help for the actions
'tooltip-t-print' => '這個頁面的可打印版本',

# Special:NewFiles
'showhidebots' => '($1機械人)',

);

==> mediawiki-1.15.5p3.tgz: mediawiki/languages/messages/MessagesZh_hk.php <==
<?php
/** Chinese (Hong Kong) (‪中文(香港)‬)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author PhiLiP
 * @author Wong128hk
 * @author Yuyu
 */

$fallback = 'zh-hant';

$messages = array(
# User preference toggles
'tog-watchlisthidebots' => '監視列表中隱藏機械人的編輯',
'tog-norollbackdiff'    => '進行回退後略過差異比較',

# Dates
'sunday'        => '星期日',
'monday'        => '星期一',
'tuesday'       => '星期二',
'wednesday'     => '星期三',
'thursday'      => '星期四',
'friday'        => '星期五',
'saturday'      => '星期六',
'sun'           => '日',
'mon'           => '一',
'tue'           => '二',
'wed'           => '三',
'thu'           => '四',
'fri'           => '五',
'sat'           => '六',
'january'       => '1月',
'february'      => '2月',
'march'         => '3月',
'april'         => '4月',
'may_long'      => '5月',
'june'          => '6月',
'july'          => '7月',
'august'        => '8月',
'september'     => '9月',
'october'       => '10月',
'november'      => '11月',
'december'      => '12月',
'january-gen'   => '一月',
'february-gen'  => '二月',
'march-gen'     => '三月',
'april-gen'     => '四月',
'may-gen'       => '五月',
'june-gen'      => '六月',
'july-gen'      => '七月',
'august-gen'    => '八月',
'september-gen' => '九月',
'october-gen'   => '十月',
'november-gen'  => '十一月',
'december-gen'  => '十二月',
'jan'           => '1月',

'printableversion' => '可打印版',
'print'            => '打印',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'portal'      => '社群入口',
'privacy'     => '私隱政策',
'privacypage' => 'Project:私隱政策',

# Groups
'group-bot' => '機械人',

'group-bot-member' => '機械人',

'grouppage-bot' => '{{ns:project}}:機械人',

# Recent changes
'rcshowhidebots' => '$1機械人的編輯',

# Move page
'move-redirect-suppressed' => '已禁止重新定向',

# Tooltip help for the actions
'tooltip-t-print' => '這個頁面的可打印版本',

# Special:NewFiles
'showhidebots' => '($1機械人)',

);
